# Archived Documentation

This directory contains historical design documents and completed implementation plans.

These documents are preserved for reference but are no longer actively maintained.

## Contents

| Document | Status | Notes |
|----------|--------|-------|
| [LMSTUDIO_PROVIDER_FIX_PLAN.md](LMSTUDIO_PROVIDER_FIX_PLAN.md) | ✅ Completed | LMStudioProvider implemented Dec 2024 |
| [FEATURE_PARITY_PLAN.md](FEATURE_PARITY_PLAN.md) | Historical | Competitor analysis snapshot |
| [CODEBASE_CONSOLIDATION_PLAN.md](CODEBASE_CONSOLIDATION_PLAN.md) | Historical | Technical debt tracking |

## Active Documentation

For current documentation, see:
- [docs/README.md](../README.md) - Documentation index
- [docs/guides/](../guides/) - How-to guides
- [docs/reference/](../reference/) - Technical reference
